
__title__ = 'minchin.pelican.plugins.summary'
__version__ = "1.1.0"
__description__ = 'This Pelcan plugin allows easy, variable length summaries directly embedded into the body of your articles.'
__author__ = 'William Minchin'
__email__ = 'w_minchin@hotmail.com'
__url__ = 'https://github.com/MinchinWeb/minchin.pelican.plugins.summary'
__license__ = 'GNU Affero General Public License v3'

from .summary import *
